EasyExtend.langlets.p4d.langlet.LangletTransformer

Package EasyExtend :: Package langlets :: Package p4d :: Module langlet :: Class LangletTransformer |
[hide private]
[frames] | no frames]

# Class LangletTransformer

                   object --+
                            |
    eetransformer.Transformer --+
                                |
                               LangletTransformer

Known Subclasses:
  - InteractiveTransformer

Defines langlet specific CST transformations.

Instance Methods | [hide private]
subscript(self, node) |
NAME(self, node) |
SPECNUM(self, node) |
p4d_attr_access(self, node) p4d_attr_access: '@' ( NAME | '*') |
p4d_accessor(self, node) p4d_accessor: '.' p4d_attr_access | '::' NAME | '.' '(' ['.'] test ')' |
p4d_compound_stmt(self, node) p4d_compound_stmt: ['elm' | NAME '='] p4d_element ':' p4d_suite |
p4d_string(self, p4dnode) |
build_p4d_compound_stmt(self, node, xmlnode=None) p4d_compound_stmt: [NAME '='] p4d_element ':' p4d_suite |
build_p4d_name(self, node) p4d_name: NAME (':' NAME)* |
build_p4d_element(self, node) p4d_element: p4d_name ['(' [p4d_attribute_list] ')'] |
build_p4d_attribute(self, node) p4d_attribute: p4d_name '=' ['&'] test |
build_p4d_simple_stmt(self, node) p4d_simple_stmt: (p4d_element | p4d_expr) NEWLINE |
build_p4d_stmt(self, node, xmlnode) p4d_stmt: p4d_simple_stmt | p4d_compound_stmt |
build_p4d_suite(self, node, xmlnode) p4d_suite: p4d_simple_stmt | NEWLINE INDENT p4d_stmt+ DEDENT |
build_p4d_expr(self, node) p4d_expr: '&' test | '(' [ p4d_expr (',' p4d_expr)] ')' | STRING | NUMBER | SPECNUM | P4D_Comment |
Inherited from `eetransformer.Transformer`: `__init__`, `contains_node`, `general_transform`, `get_container`, `is_main`, `is_node`, `mark_node`, `node_stack`, `prepare`, `run`, `terminate`, `unmark_node` Inherited from `eetransformer.Transformer` (private): `_find_handler`, `_load_exospace` Inherited from `object`: `__delattr__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__repr__`, `__setattr__`, `__str__`

Properties | [hide private]
Inherited from `object`: `__class__`

Method Details | [hide private]

### subscript(self, node) |
Decorators: `@transform`

### NAME(self, node) |
Decorators: `@transform`

### SPECNUM(self, node) |
Decorators: `@transform`

### p4d_attr_access(self, node) |
p4d_attr_access: '@' ( NAME | '*') Decorators: `@transform`

### p4d_accessor(self, node) |
p4d_accessor: '.' p4d_attr_access | '::' NAME | '.' '(' ['.'] test ')' Decorators: `@transform`

### p4d_compound_stmt(self, node) |
p4d_compound_stmt: ['elm' | NAME '='] p4d_element ':' p4d_suite Decorators: `@transform`